==> haskell-structured-0.1.1-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-1VxHgy8UpSBGE2HW4rnrpp
key:                  structured-0.1.1-1VxHgy8UpSBGE2HW4rnrpp
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  774b47577c9429e89db56a86cadb0f01
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.2.8/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-1VxHgy8UpSBGE2HW4rnrpp
depends:
    aeson-2.1.2.1-9T6l6SxZl5u1C3PaFHxalW array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-3uI24z1Sq0HGbwd5beeMUi binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-JynHLbpSPE72B4j6uWctY4
    scientific-0.3.7.0-JDywD8dnuxJJkMv2HmTQaQ
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP text-1.2.5.0
    time-compat-1.9.6.1-Aal5jKqaxKdJBR5uoMavds transformers-0.5.6.2
    unordered-containers-0.2.20-AzoOiKjV26Z32LkoSmNfI7
    uuid-types-1.0.5.1-Am8doqYfzTb18DnxZzBlHL
    vector-0.13.1.0-JX40x5KeA95953did9SvPW

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-structured-0.1.1-193-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-structured.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 structured
version:              0.1.1
visibility:           public
id:                   structured-0.1.1-3LgrOhixugBHuhOupqNUZe
key:                  structured-0.1.1-3LgrOhixugBHuhOupqNUZe
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Structure (hash) of your data types
description:
    Calculate the hash of a data structure.
    It can be used as a magic number for the serialization formats.
    See <https://hackage.haskell.org/package/binary-tagged binary-tagged>
    for a @binary@ bindings.

category:             Data
abi:                  731ef01a6d6b009e63118e016699498c
exposed:              True
exposed-modules:      Data.Structured Data.Structured.Internal
hidden-modules:       Data.Structured.MD5
import-dirs:          /usr/lib/ghc-9.2.8/site-local/structured-0.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/structured-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-structured
hs-libraries:         HSstructured-0.1.1-3LgrOhixugBHuhOupqNUZe
depends:
    aeson-2.1.2.1-A1BsFbrv9iTYSCFmVNKuj array-0.5.4.0 base-4.16.4.0
    base16-bytestring-1.0.2.0-AK96RZYr55lHVf4WSwGA81 binary-0.8.9.0
    bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-4PDYVYgOfaOHbKjFqbnqvX
    scientific-0.3.7.0-32sSMVZGVJI9kBL7DeEJ6v
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP text-1.2.5.0
    time-compat-1.9.6.1-D2t6ohyekdSIklEQ3NZcRl transformers-0.5.6.2
    unordered-containers-0.2.20-E7OuZmBexWvK28rs1X57rg
    uuid-types-1.0.5.1-6gzlI81cNETEmz8VFoQG7M
    vector-0.13.1.0-1cpgbj3eXUqGZ3uVszXgJ9

haddock-interfaces:   /usr/share/doc/haskell-structured/html/structured.haddock
haddock-html:         /usr/share/doc/haskell-structured/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
